@@ -1,5 +1,5 @@
 from .cfp import CfPForm, QuestionForm, SubmissionTypeForm, TrackForm
-from .event import EventForm, EventSettingsForm
+from .event import EventForm
 from .review import ReviewForm
 from .submission import AnonymiseForm, SubmissionForm
 
@@ -7,7 +7,6 @@ __all__ = [
     "AnonymiseForm",
     "CfPForm",
     "EventForm",
-    "EventSettingsForm",
     "QuestionForm",
     "ReviewForm",
     "SubmissionForm",
